@@ -26,6 +26,13 @@ sub new
     return bless { graph => $graph, chain => $chain, amine => $amine }, $class;
 }
 
+sub isa
+{
+    my( $self, $class ) = @_;
+    return 1 if $class eq ChemOnomatopist::Chain::Amine::;
+    return $self->{chain}->isa( $class );
+}
+
 sub vertices()
 {
     my $self = shift;
@@ -47,6 +54,7 @@ sub heteroatom_positions
 }
 
 sub is_hydrocarbon() { '' }
+sub is_main() { $_[0]->{is_main} }
 
 sub needs_substituent_locants() { $_[0]->{chain}->length > 0 }
 
