@@ -6,7 +6,6 @@ package ChemOnomatopist::Chain::Circular;
 use strict;
 use warnings;
 
-use ChemOnomatopist;
 use ChemOnomatopist::Chain;
 use ChemOnomatopist::Chain::Monocycle;
 use ChemOnomatopist::Elements qw( %elements );
@@ -145,7 +144,7 @@ sub indicated_hydrogens()
     for my $i (0..$#vertices) {
         # Rough interpretation of BBv2 P-14.7.1 and P-22.2.2.1.4
         next unless $vertices[$i]->{hcount};
-        my $element = ChemOnomatopist::element( $vertices[$i] );
+        my $element = ChemOnomatopist::Util::element( $vertices[$i] );
         if( $element eq 'C' ) {
             if(  $vertices[$i]->{hcount} == 2 ||
                 ($graph->degree( $vertices[$i] ) == 3 &&
@@ -176,8 +175,8 @@ sub locants(@)
     my $letter = 'a';
     for my $i (0..$#vertices) {
         if( $graph->degree( $vertices[$i] ) == 2 ||
-            !ChemOnomatopist::element( $vertices[$i] ) ||
-             ChemOnomatopist::element( $vertices[$i] ) ne 'C' ) {
+            !ChemOnomatopist::Util::element( $vertices[$i] ) ||
+             ChemOnomatopist::Util::element( $vertices[$i] ) ne 'C' ) {
             $pos++;
             $locant_map{$i} = $pos;
             $letter = 'a';
@@ -212,7 +211,8 @@ sub indicated_hydrogens_part()
         my $single_H = shift @indicated_hydrogens if @indicated_hydrogens % 2;
         if( @indicated_hydrogens ) {
             if( $self->number_of_indicated_hydrogens < $self->length ) {
-                $part->append_locants( $self->locants( @indicated_hydrogens ) );
+                $part->append_locants( sort { ChemOnomatopist::cmp_locants( $a, $b ) }
+                                            $self->locants( @indicated_hydrogens ) );
             }
             $part .= ChemOnomatopist::IUPAC_numerical_multiplier( scalar @indicated_hydrogens );
             $part->[-1] .= 'a' unless $part =~ /[ai]$/;
