@@ -33,16 +33,17 @@ sub new
 
     # Adjust the order
     if( any { ChemOnomatopist::Util::element( $_ ) ne 'C' } @vertices ) {
-        # Find the order so as N is closest to the beginning of the chain
+        # Flip the order to get a heteroatom closest to the beginning of the chain
         my $first = first { ChemOnomatopist::Util::element( $vertices[$_] )    ne 'C' } 0..$#vertices;
         my $last  = first { ChemOnomatopist::Util::element( $vertices[-1-$_] ) ne 'C' } 0..$#vertices;
         @vertices = reverse @vertices if $last < $first;
         push @vertices, shift @vertices;
 
-        # Phenanthridine has a strict order
-        if( (grep { ChemOnomatopist::Util::element( $_ ) eq 'N' } @vertices) == 1 &&
-            ChemOnomatopist::Util::element( $vertices[5] ) ne 'N' ) {
-            die "cannot handle complicated cyclic compounds\n";
+        # Phenanthridine and its derivatives have a strict order
+        if( (grep { ChemOnomatopist::Util::element( $_ ) ne 'C' } @vertices) == 1 &&
+            (grep { ChemOnomatopist::Util::element( $_ ) =~ /^(As|N|O|P)$/ } @vertices) == 1 &&
+            ChemOnomatopist::Util::element( $vertices[5] ) eq 'C' ) {
+            die "unknown phenanthrene derivative\n";
         }
     } else {
         for (1..5) {
@@ -109,24 +110,21 @@ sub prefix()
 
     my @heteroatom_locants = $self->locants( $self->heteroatom_positions );
 
-    if( all { $_ eq 'N' } $self->heteroatoms ) {
-        if( @heteroatom_locants == 1 && all { $_ == 5 } @heteroatom_locants ) {
-            return ChemOnomatopist::Name->new( 'phenanthridine' );
-        }
-        if( @heteroatom_locants == 2 &&
-            (
-              ( $heteroatom_locants[0] == 1 && $heteroatom_locants[1] >= 7 && $heteroatom_locants[1] <= 10 ) ||
-              ( $heteroatom_locants[0] == 2 && $heteroatom_locants[1] >= 7 && $heteroatom_locants[1] <=  9 ) ||
-              ( $heteroatom_locants[0] == 3 && $heteroatom_locants[1] >= 7 && $heteroatom_locants[1] <=  8 ) ||
-              ( $heteroatom_locants[0] == 4 && $heteroatom_locants[1] == 7 )
-            ) ) {
-            return ChemOnomatopist::Name->new( 'phenanthroline' );
-        }
+    if( @heteroatom_locants == 1 && all { $_ == 5 } @heteroatom_locants ) {
+        return ChemOnomatopist::Name->new( 'arsanthridine' )        if all { $_ eq 'As' } $self->heteroatoms;
+        return ChemOnomatopist::Name->new( 'phenanthridine' )       if all { $_ eq 'N'  } $self->heteroatoms;
+        return ChemOnomatopist::Name->new( '6H-dibenzo[b,d]pyran' ) if all { $_ eq 'O'  } $self->heteroatoms;
+        return ChemOnomatopist::Name->new( 'phosphanthridine' )     if all { $_ eq 'P'  } $self->heteroatoms;
     }
 
-    if( @heteroatom_locants == 1 && all { $_ == 5 } @heteroatom_locants ) {
-        return ChemOnomatopist::Name->new( 'arsanthridine' )    if all { $_ eq 'As' } $self->heteroatoms;
-        return ChemOnomatopist::Name->new( 'phosphanthridine' ) if all { $_ eq 'P'  } $self->heteroatoms;
+    if( @heteroatom_locants == 2 && (all { $_ eq 'N' } $self->heteroatoms) &&
+        (
+          ( $heteroatom_locants[0] == 1 && $heteroatom_locants[1] >= 7 && $heteroatom_locants[1] <= 10 ) ||
+          ( $heteroatom_locants[0] == 2 && $heteroatom_locants[1] >= 7 && $heteroatom_locants[1] <=  9 ) ||
+          ( $heteroatom_locants[0] == 3 && $heteroatom_locants[1] >= 7 && $heteroatom_locants[1] <=  8 ) ||
+          ( $heteroatom_locants[0] == 4 && $heteroatom_locants[1] == 7 )
+        ) ) {
+        return ChemOnomatopist::Name->new( 'phenanthroline' );
     }
 
     return ChemOnomatopist::Name->new( 'phenanthrene' ) if $self->is_hydrocarbon;
