@@ -11,17 +11,17 @@ use parent ChemOnomatopist::Chain::Circular::;
 use ChemOnomatopist::Util::Graph qw(
     graph_without_edge_attributes
     merge_graphs
-    subgraph
 );
 use Graph::Nauty qw( are_isomorphic );
 use Graph::Undirected;
+use List::Util qw( first );
 use Set::Object qw( set );
 
 sub new
 {
     my( $class, $graph, @cycles ) = @_;
 
-    my $subgraph = subgraph( $graph, map { $_->vertices } @cycles );
+    my $subgraph = $graph->subgraph( map { $_->vertices } @cycles );
 
     # Constructing the connectivity graph for cycles
     my $connectivity_graph = Graph::Undirected->new( refvertexed => 1 );
@@ -35,13 +35,13 @@ sub new
     for my $cycle (@cycles) {
         next unless scalar( grep { $subgraph->degree( $_->[0] ) == 3 &&
                                    $subgraph->degree( $_->[1] ) == 3 }
-                                 subgraph( $graph, $cycle->vertices )->edges ) == 3;
+                                 $graph->subgraph( $cycle->vertices )->edges ) == 3;
         $common_ring = $cycle;
     }
 
     # Finding the correct order of cycles, flipping if needed
     my $common_ring_pos = @cycles % 2 ? (@cycles - 1) / 2 : @cycles / 2 - 1;
-    my( $start ) = grep { $connectivity_graph->degree( $_ ) == 1 } @cycles;
+    my $start = first { $connectivity_graph->degree( $_ ) == 1 } @cycles;
     my @cycles_in_order = Graph::Traversal::DFS->new( $connectivity_graph,
                                                       start => $start )->dfs;
     if( !@cycles % 2 && $cycles_in_order[$common_ring_pos] != $common_ring ) {
@@ -49,24 +49,24 @@ sub new
     }
 
     # Finding the atom in the common ring which will get the lowest number
-    $subgraph = subgraph( $graph, $common_ring->vertices );
+    $subgraph = $graph->subgraph( $common_ring->vertices );
     $subgraph->delete_edges( map { @$_ }
-                             map { subgraph( $graph, $_->vertices )->edges }
+                             map { $graph->subgraph( $_->vertices )->edges }
                                  ( $cycles_in_order[$common_ring_pos-1],
                                    $cycles_in_order[$common_ring_pos+1] ) );
-    my( $short_edge ) = grep { $subgraph->degree( $_->[0] ) == 1 &&
-                               $subgraph->degree( $_->[1] ) == 1 }
-                               $subgraph->edges;
+    my $short_edge = first { $subgraph->degree( $_->[0] ) == 1 &&
+                             $subgraph->degree( $_->[1] ) == 1 }
+                             $subgraph->edges;
     my( $junction ) = (set( $cycles_in_order[$common_ring_pos-1]->vertices ) *
                        set( @$short_edge ))->members;
 
     # Finding the candidates of the starting atom
-    $subgraph = subgraph( $graph, $cycles_in_order[0]->vertices );
+    $subgraph = $graph->subgraph( $cycles_in_order[0]->vertices );
     $subgraph->delete_vertices(   $cycles_in_order[1]->vertices );
     my @candidates = grep { $subgraph->degree( $_ ) == 1 } $subgraph->vertices;
 
     # Finding the first and the last atom in the enumeration order
-    $subgraph = subgraph( $graph, map { $_->vertices } @cycles );
+    $subgraph = $graph->subgraph( map { $_->vertices } @cycles );
     my $shortest_paths = $subgraph->single_source_shortest_paths( $junction );
     my $min_length;
     my $first;
@@ -83,7 +83,7 @@ sub new
         }
     }
 
-    my( $last ) = grep { $subgraph->degree( $_ ) == 3 }
+    my $last = first { $subgraph->degree( $_ ) == 3 }
                        $subgraph->neighbours( $first );
 
     # Deleting chords and connection between first and last atoms
