@@ -7,6 +7,7 @@ use strict;
 use warnings;
 
 use ChemOnomatopist::Chain::Circular;
+use ChemOnomatopist::Group::AcidHalide;
 use ChemOnomatopist::Group::AcylHalide;
 use ChemOnomatopist::Group::Aldehyde;
 use ChemOnomatopist::Group::Amide;
@@ -28,6 +29,9 @@ use ChemOnomatopist::Group::Imine;
 use ChemOnomatopist::Group::Isocyanate;
 use ChemOnomatopist::Group::Isocyanide;
 use ChemOnomatopist::Group::Ketone;
+use ChemOnomatopist::Group::Nitramide;
+use ChemOnomatopist::Group::Sulfinamide;
+use ChemOnomatopist::Group::Sulfonamide;
 use ChemOnomatopist::Group::SulfinicAcid;
 use ChemOnomatopist::Group::SulfonicAcid;
 use ChemOnomatopist::Group::Urea;
@@ -46,14 +50,18 @@ our @order = (
     ChemOnomatopist::Group::Carboxyl::,
     ChemOnomatopist::Group::SulfonicAcid::,
     ChemOnomatopist::Group::SulfinicAcid::,
-    ChemOnomatopist::Group::AcylHalide::, # FIXME: Is this correct?
     # Anhydrides
     ChemOnomatopist::Group::Ester::,
     # Acid halides and pseudohalides
+    ChemOnomatopist::Group::AcidHalide::,
+    ChemOnomatopist::Group::AcylHalide::,
     # Amides
     ChemOnomatopist::Group::Urea::,
+    ChemOnomatopist::Group::Sulfonamide::,
+    ChemOnomatopist::Group::Sulfinamide::,
     ChemOnomatopist::Group::Amide::,
     ChemOnomatopist::Group::Guanidine::,
+    ChemOnomatopist::Group::Nitramide::, # FIXME: Is this correct?
     # Hydrazides
     ChemOnomatopist::Group::Hydrazide::,
     # Imides
@@ -88,6 +96,7 @@ sub new
 }
 
 sub element() { $_[0]->{element} }
+sub charge() { 0 }
 
 sub is_part_of_chain() { '' }
 
