@@ -21,6 +21,6 @@ sub charge() { ChemOnomatopist::charge( $_[0]->{atom} ) }
 sub is_terminal() { 1 }
 
 sub prefix() { ChemOnomatopist::Name->new( 'amino' ) }
-sub suffix() { ChemOnomatopist::Name->new( $_[0]->charge == -1 ? 'aminide' : 'amine' ) }
+sub suffix() { ChemOnomatopist::Name->new( $_[0]->charge && $_[0]->charge == -1 ? 'aminide' : 'amine' ) }
 
 1;
