@@ -9,7 +9,7 @@ use warnings;
 use parent ChemOnomatopist::Group::, ChemOnomatopist::Chain::;
 
 use Chemistry::OpenSMILES qw( is_double_bond );
-use List::Util qw( any );
+use List::Util qw( any first );
 
 sub new
 {
@@ -33,11 +33,14 @@ sub needs_substituent_locants()
 {
     my( $self ) = @_;
 
-    for my $vertex ($self->vertices) {
-        return '' if any { is_double_bond( $self->graph, $vertex, $_ ) }
-                         $self->graph->neighbours( $vertex );
+    my $graph = $self->graph;
+    my $parent = $self->{parent};
+    if( $parent ) {
+        my $vertex = first { $graph->has_edge( $parent, $_ ) } $self->vertices;
+        return '' if is_double_bond( $self->graph, $vertex, $parent );
     }
 
+    return 1 if $self->number_of_isotopes;
     return $self->number_of_branches > 1 && $self->number_of_branches < $self->max_valence;
 }
 
