@@ -10,7 +10,7 @@ use parent ChemOnomatopist::Group::;
 
 use ChemOnomatopist::Elements qw( %elements );
 
-sub is_prefix_only() { return 1 }
+sub is_prefix_only() { 1 }
 
 # Compiled from BBv2 Table 5.1 (P-59.1.9)
 sub prefix {
