@@ -8,6 +8,6 @@ use warnings;
 
 use parent ChemOnomatopist::Name::Part::;
 
-sub is_numeric() { return $_[0]->{value} =~ /^\]?\d+(,\d+)*[-\]]?$/ }
+sub is_numeric() { $_[0]->{value} =~ /^\]?\d+(,\d+)*[-\]]?$/ }
 
 1;
