@@ -282,21 +282,23 @@ sub merge_graphs
     return $merged;
 }
 
+# Returns a list of neighbours at certain distance from the central vertex.
+# Distance of 0 means immediate neighbours, distance of 1 means neighbours of neighbours and so on.
 sub neighbours_at_distance
 {
-    my( $graph, $vertex, $from, $distance, $path ) = @_;
+    my( $graph, $vertex, $distance, $seen ) = @_;
 
-    my @neighbours = grep { !$path->has( $_ ) }
+    my @neighbours = grep { !$seen->has( $_ ) }
                           $graph->neighbours( $vertex );
-    my @double_bonds = grep { is_double_bond( $graph, $vertex, $_ ) }
-                            $graph->neighbours( $vertex );
 
     if( $distance ) {
-        return @double_bonds,
-               map { neighbours_at_distance( $graph, $_, $vertex, $distance-1, set( @$path, $vertex ) ) }
+        return map { neighbours_at_distance( $graph, $_, $distance-1, set( @$seen, $vertex ) ) }
                    @neighbours;
     } else {
-        return @double_bonds, @neighbours;
+        # This is needed per BBv3 P-92.1.4
+        my @double_bonded_neighbours = grep { is_double_bond( $graph, $vertex, $_ ) }
+                                            $graph->neighbours( $vertex );
+        return @double_bonded_neighbours, @neighbours;
     }
 }
 
